@@ -8,11 +8,11 @@ import (
 	"strings"
 	"time"
 
-	"github.com/aelsabbahy/goss"
-	"github.com/aelsabbahy/goss/outputs"
-	"github.com/aelsabbahy/goss/resource"
-	"github.com/aelsabbahy/goss/system"
-	"github.com/aelsabbahy/goss/util"
+	"github.com/goss-org/goss"
+	"github.com/goss-org/goss/outputs"
+	"github.com/goss-org/goss/resource"
+	"github.com/goss-org/goss/system"
+	"github.com/goss-org/goss/util"
 
 	"github.com/fatih/color"
 	"github.com/urfave/cli"
@@ -27,6 +27,7 @@ func newRuntimeConfigFromCLI(c *cli.Context) *util.Config {
 		AnnounceToCLI:     true,
 		Cache:             c.Duration("cache"),
 		Debug:             c.Bool("debug"),
+		LogLevel:          c.GlobalString("loglevel"),
 		Endpoint:          c.String("endpoint"),
 		FormatOptions:     c.StringSlice("format-options"),
 		IgnoreList:        c.GlobalStringSlice("exclude-attr"),
@@ -73,6 +74,12 @@ func main() {
 	app.Name = "goss"
 	app.Usage = "Quick and Easy server validation"
 	app.Flags = []cli.Flag{
+		cli.StringFlag{
+			Name:   "loglevel, L",
+			Value:  "FATAL",
+			Usage:  "Goss log verbosity level",
+			EnvVar: "GOSS_LOGLEVEL",
+		},
 		cli.StringFlag{
 			Name:   "gossfile, g",
 			Value:  "./goss.yaml",
@@ -168,19 +175,19 @@ func main() {
 					EnvVar: "GOSS_FMT_OPTIONS",
 				},
 				cli.DurationFlag{
-					Name:   "cache,c",
+					Name:   "cache, c",
 					Usage:  "Time to cache the results",
 					Value:  5 * time.Second,
 					EnvVar: "GOSS_CACHE",
 				},
 				cli.StringFlag{
-					Name:   "listen-addr,l",
+					Name:   "listen-addr, l",
 					Value:  ":8080",
 					Usage:  "Address to listen on [ip]:port",
 					EnvVar: "GOSS_LISTEN",
 				},
 				cli.StringFlag{
-					Name:   "endpoint,e",
+					Name:   "endpoint, e",
 					Value:  "/healthz",
 					Usage:  "Endpoint to expose",
 					EnvVar: "GOSS_ENDPOINT",
@@ -420,8 +427,8 @@ const msgFormat string = `WARNING: goss for this platform (%q) is alpha-quality,
 
 You should not expect everything to work. Treat linux as the canonical behaviour to expect.
 
-Please see https://github.com/aelsabbahy/goss/tree/master/docs/platform-feature-parity.md to set your expectations and see progress.
-Please file issues via https://github.com/aelsabbahy/goss/issues/new/choose
+Please see https://github.com/goss-org/goss/tree/master/docs/platform-feature-parity.md to set your expectations and see progress.
+Please file issues via https://github.com/goss-org/goss/issues/new/choose
 Pull requests and bug reports very welcome.`
 
 func fatalAlphaIfNeeded(c *cli.Context) {
