@@ -7,11 +7,11 @@ import (
 	"testing"
 	"time"
 
-	"github.com/aelsabbahy/goss/outputs"
-	"github.com/aelsabbahy/goss/util"
+	"github.com/goss-org/goss/outputs"
+	"github.com/goss-org/goss/util"
 )
 
-func checkErr(t *testing.T, err error, format string, a ...interface{}) {
+func checkErr(t *testing.T, err error, format string, a ...any) {
 	t.Helper()
 	if err == nil {
 		return
