@@ -6,9 +6,9 @@ import (
 	"io"
 	"time"
 
-	"github.com/aelsabbahy/goss/resource"
-	"github.com/aelsabbahy/goss/util"
 	"github.com/fatih/color"
+	"github.com/goss-org/goss/resource"
+	"github.com/goss-org/goss/util"
 )
 
 type JsonOneline struct{}
@@ -23,7 +23,7 @@ func (r JsonOneline) Output(w io.Writer, results <-chan []resource.TestResult,
 	color.NoColor = true
 	testCount := 0
 	failed := 0
-	var resultsOut []map[string]interface{}
+	var resultsOut []map[string]any
 	for resultGroup := range results {
 		for _, testResult := range resultGroup {
 			if !testResult.Successful {
@@ -37,14 +37,14 @@ func (r JsonOneline) Output(w io.Writer, results <-chan []resource.TestResult,
 		}
 	}
 
-	summary := make(map[string]interface{})
+	summary := make(map[string]any)
 	duration := time.Since(startTime)
 	summary["test-count"] = testCount
 	summary["failed-count"] = failed
 	summary["total-duration"] = duration
 	summary["summary-line"] = fmt.Sprintf("Count: %d, Failed: %d, Duration: %.3fs", testCount, failed, duration.Seconds())
 
-	out := make(map[string]interface{})
+	out := make(map[string]any)
 	out["results"] = resultsOut
 	out["summary"] = summary
 
