@@ -3,10 +3,12 @@ package outputs
 import (
 	"fmt"
 	"io"
+	"log"
+	"strings"
 	"time"
 
-	"github.com/aelsabbahy/goss/resource"
-	"github.com/aelsabbahy/goss/util"
+	"github.com/goss-org/goss/resource"
+	"github.com/goss-org/goss/util"
 )
 
 type Rspecish struct{}
@@ -26,12 +28,15 @@ func (r Rspecish) Output(w io.Writer, results <-chan []resource.TestResult,
 		for _, testResult := range resultGroup {
 			switch testResult.Result {
 			case resource.SUCCESS:
+				logTrace("TRACE", "SUCCESS", testResult, false)
 				fmt.Fprintf(w, green("."))
 			case resource.SKIP:
+				logTrace("TRACE", "SKIP", testResult, false)
 				fmt.Fprintf(w, yellow("S"))
 				failedOrSkippedGroup = append(failedOrSkippedGroup, testResult)
 				skipped++
 			case resource.FAIL:
+				logTrace("WARN", "FAIL", testResult, false)
 				fmt.Fprintf(w, red("F"))
 				failedOrSkippedGroup = append(failedOrSkippedGroup, testResult)
 				failed++
@@ -46,9 +51,13 @@ func (r Rspecish) Output(w io.Writer, results <-chan []resource.TestResult,
 	fmt.Fprint(w, "\n\n")
 	fmt.Fprint(w, failedOrSkippedSummary(failedOrSkipped))
 
-	fmt.Fprint(w, summary(startTime, testCount, failed, skipped))
+	outstr := summary(startTime, testCount, failed, skipped)
+	fmt.Fprint(w, outstr)
+	resstr := strings.ReplaceAll(outstr, "\n", " ")
 	if failed > 0 {
+		log.Printf("[WARN] FAIL SUMMARY: %s", resstr)
 		return 1
 	}
+	log.Printf("[INFO] OK SUMMARY: %s", resstr)
 	return 0
 }
