@@ -11,7 +11,7 @@ import (
 	"strings"
 	"time"
 
-	"github.com/aelsabbahy/goss/util"
+	"github.com/goss-org/goss/util"
 )
 
 type HTTP interface {
