@@ -11,10 +11,10 @@ import (
 
 	"github.com/fatih/color"
 
-	"github.com/aelsabbahy/goss/outputs"
-	"github.com/aelsabbahy/goss/resource"
-	"github.com/aelsabbahy/goss/system"
-	"github.com/aelsabbahy/goss/util"
+	"github.com/goss-org/goss/outputs"
+	"github.com/goss-org/goss/resource"
+	"github.com/goss-org/goss/system"
+	"github.com/goss-org/goss/util"
 )
 
 func getGossConfig(vars string, varsInline string, specFile string) (cfg *GossConfig, err error) {
@@ -99,6 +99,10 @@ func ValidateResults(c *util.Config) (results <-chan []resource.TestResult, err
 // by the typical CLI invocation and will produce output to StdOut.  Use
 // ValidateResults for programmatic access
 func Validate(c *util.Config, startTime time.Time) (code int, err error) {
+	err = setLogLevel(c)
+	if err != nil {
+		return 1, err
+	}
 	outputConfig := util.OutputConfig{
 		FormatOptions: c.FormatOptions,
 	}
